import paho.mqtt.client as mqtt
from config.settings import Settings

class MqttClient:
    def __init__(self):
        self.client = mqtt.Client()
        if Settings.MQTT_USERNAME:
            self.client.username_pw_set(Settings.MQTT_USERNAME, Settings.MQTT_PASSWORD)
        if Settings.MQTT_TLS:
            self.client.tls_set()
        self.client.on_connect = self.on_connect
        self.client.on_message = None  # 由外部设置

    def connect(self):
        self.client.connect(Settings.MQTT_BROKER, Settings.MQTT_PORT)
        self.client.loop_start()

    def disconnect(self):
        self.client.loop_stop()
        self.client.disconnect()

    def subscribe(self, topic, qos=0):
        self.client.subscribe(topic, qos)

    def publish(self, topic, payload, qos=0):
        self.client.publish(topic, payload, qos)

    def set_on_message(self, callback):
        self.client.on_message = callback

    def on_connect(self, client, userdata, flags, rc):
        for item in Settings.MQTT_TOPICS:
            if isinstance(item, (list, tuple)) and len(item) == 2:
                topic, qos = item
            else:
                topic, qos = item, 0
            client.subscribe(topic, qos) 